# nautilus

[![Join the chat at https://gitter.im/AlecAivazis/nautilus](https://badges.gitter.im/AlecAivazis/nautilus.svg)](https://gitter.im/AlecAivazis/nautilus?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Build Status](https://travis-ci.org/AlecAivazis/nautilus.svg?branch=master)](https://travis-ci.org/AlecAivazis/nautilus)
[![Coverage Status](https://coveralls.io/repos/github/AlecAivazis/nautilus/badge.svg?branch=travis-config)](https://coveralls.io/github/AlecAivazis/nautilus?branch=master)

A framework for building microservice applications based on the flux architecture.

Full documentation is hosted [here](http://alecaivazis.github.io/nautilus/).

## Requirements
* Python 3.4
